summaryrefslogtreecommitdiff
path: root/source
diff options
context:
space:
mode:
authorRobert Moore <Robert.Moore@intel.com>2010-01-19 13:39:26 -0800
committerRobert Moore <Robert.Moore@intel.com>2010-01-19 13:39:26 -0800
commitbce1fbe326516c32688a30a62d1e7a0335bd83ff (patch)
tree64debf0be1cc6318a84ce0ca0dd0371696db4215 /source
parent2cd7f64bf8097ea8e864dafc01c1439d37741afa (diff)
Remove obsolete ACPI_INTEGER (acpi_integer) type.
This type was introduced as the code was migrated from ACPI 1.0 (with 32-bit AML integers) to ACPI 2.0 (with 64-bit integers). It is now obsolete and this change removes it from the ACPICA code base, replaced by UINT64. The original typedef has been retained for now for compatibility with existing device driver code.
Diffstat (limited to 'source')
-rw-r--r--source/compiler/aslanalyze.c2
-rw-r--r--source/compiler/aslcompiler.h4
-rw-r--r--source/compiler/aslcompiler.y2
-rw-r--r--source/compiler/aslopcodes.c2
-rw-r--r--source/compiler/asloperands.c2
-rw-r--r--source/compiler/aslresource.c2
-rw-r--r--source/compiler/asltransform.c18
-rw-r--r--source/compiler/asltree.c2
-rw-r--r--source/compiler/aslutils.c14
-rw-r--r--source/components/debugger/dbexec.c4
-rw-r--r--source/components/dispatcher/dsfield.c10
-rw-r--r--source/components/dispatcher/dsobject.c2
-rw-r--r--source/components/events/evregion.c4
-rw-r--r--source/components/events/evrgnini.c2
-rw-r--r--source/components/executer/exconfig.c2
-rw-r--r--source/components/executer/exconvrt.c12
-rw-r--r--source/components/executer/exfield.c6
-rw-r--r--source/components/executer/exfldio.c48
-rw-r--r--source/components/executer/exmisc.c14
-rw-r--r--source/components/executer/exoparg1.c14
-rw-r--r--source/components/executer/exoparg2.c4
-rw-r--r--source/components/executer/exoparg3.c2
-rw-r--r--source/components/executer/exoparg6.c8
-rw-r--r--source/components/executer/exregion.c28
-rw-r--r--source/components/executer/exsystem.c2
-rw-r--r--source/components/executer/exutils.c22
-rw-r--r--source/components/hardware/hwtimer.c2
-rw-r--r--source/components/parser/psargs.c2
-rw-r--r--source/components/resources/rscreate.c2
-rw-r--r--source/components/utilities/utdebug.c2
-rw-r--r--source/components/utilities/uteval.c2
-rw-r--r--source/components/utilities/utglobal.c2
-rw-r--r--source/components/utilities/utmath.c28
-rw-r--r--source/components/utilities/utmisc.c10
-rw-r--r--source/include/acevents.h2
-rw-r--r--source/include/acinterp.h42
-rw-r--r--source/include/aclocal.h2
-rw-r--r--source/include/acmacros.h12
-rw-r--r--source/include/acobject.h2
-rw-r--r--source/include/acpiosxf.h4
-rw-r--r--source/include/acrestyp.h2
-rw-r--r--source/include/actypes.h27
-rw-r--r--source/include/acutils.h20
-rw-r--r--source/os_specific/service_layers/osunixxf.c4
-rw-r--r--source/os_specific/service_layers/oswinxf.c4
-rw-r--r--source/tools/acpiexec/aecommon.h2
-rw-r--r--source/tools/acpiexec/aehandlers.c8
-rw-r--r--source/tools/acpisrc/astable.c9
48 files changed, 215 insertions, 207 deletions
diff --git a/source/compiler/aslanalyze.c b/source/compiler/aslanalyze.c
index ad4c8ddff..4cbfcd6e0 100644
--- a/source/compiler/aslanalyze.c
+++ b/source/compiler/aslanalyze.c
@@ -2157,7 +2157,7 @@ AnOtherSemanticAnalysisWalkBegin (
*/
if (((ArgNode->Asl.ParseOpcode == PARSEOP_WORDCONST) ||
(ArgNode->Asl.ParseOpcode == PARSEOP_INTEGER)) &&
- (ArgNode->Asl.Value.Integer >= (ACPI_INTEGER) ACPI_WAIT_FOREVER))
+ (ArgNode->Asl.Value.Integer >= (UINT64) ACPI_WAIT_FOREVER))
{
break;
}
diff --git a/source/compiler/aslcompiler.h b/source/compiler/aslcompiler.h
index c160a66f6..76bf51a8b 100644
--- a/source/compiler/aslcompiler.h
+++ b/source/compiler/aslcompiler.h
@@ -511,7 +511,7 @@ TrCreateLeafNode (
ACPI_PARSE_OBJECT *
TrCreateValuedLeafNode (
UINT32 ParseOpcode,
- ACPI_INTEGER Value);
+ UINT64 Value);
ACPI_PARSE_OBJECT *
TrLinkChildren (
@@ -718,7 +718,7 @@ UtCheckIntegerRange (
UINT32 LowValue,
UINT32 HighValue);
-ACPI_INTEGER
+UINT64
UtDoConstant (
char *String);
diff --git a/source/compiler/aslcompiler.y b/source/compiler/aslcompiler.y
index 54b10d7cd..3c12a3dfc 100644
--- a/source/compiler/aslcompiler.y
+++ b/source/compiler/aslcompiler.y
@@ -2388,7 +2388,7 @@ QWordConstExpr
ConstExprTerm
: PARSEOP_ZERO {$$ = TrCreateValuedLeafNode (PARSEOP_ZERO, 0);}
| PARSEOP_ONE {$$ = TrCreateValuedLeafNode (PARSEOP_ONE, 1);}
- | PARSEOP_ONES {$$ = TrCreateValuedLeafNode (PARSEOP_ONES, ACPI_INTEGER_MAX);}
+ | PARSEOP_ONES {$$ = TrCreateValuedLeafNode (PARSEOP_ONES, ACPI_UINT64_MAX);}
;
/* OptionalCount must appear before ByteList or an incorrect reduction will result */
diff --git a/source/compiler/aslopcodes.c b/source/compiler/aslopcodes.c
index 2dc3e9ae0..1c6eef724 100644
--- a/source/compiler/aslopcodes.c
+++ b/source/compiler/aslopcodes.c
@@ -328,7 +328,7 @@ OpcSetOptimalIntegerSize (
}
break;
- case ACPI_INTEGER_MAX:
+ case ACPI_UINT64_MAX:
/* Check for table integer width (32 or 64) */
diff --git a/source/compiler/asloperands.c b/source/compiler/asloperands.c
index 6ec955e2b..bf6dcf2cb 100644
--- a/source/compiler/asloperands.c
+++ b/source/compiler/asloperands.c
@@ -604,7 +604,7 @@ OpnDoRegion (
}
else
{
- Op->Asl.Value.Integer = ACPI_INTEGER_MAX;
+ Op->Asl.Value.Integer = ACPI_UINT64_MAX;
}
}
diff --git a/source/compiler/aslresource.c b/source/compiler/aslresource.c
index 3b4c5738c..421fde3a3 100644
--- a/source/compiler/aslresource.c
+++ b/source/compiler/aslresource.c
@@ -184,7 +184,7 @@ RsCreateBitField (
{
Op->Asl.ExternalName = Name;
- Op->Asl.Value.Integer = ((ACPI_INTEGER) ByteOffset * 8) + BitOffset;
+ Op->Asl.Value.Integer = ((UINT64) ByteOffset * 8) + BitOffset;
Op->Asl.CompileFlags |= (NODE_IS_RESOURCE_FIELD | NODE_IS_BIT_OFFSET);
}
diff --git a/source/compiler/asltransform.c b/source/compiler/asltransform.c
index dec79e272..5327a9072 100644
--- a/source/compiler/asltransform.c
+++ b/source/compiler/asltransform.c
@@ -554,7 +554,7 @@ TrDoSwitch (
NewOp = NewOp2;
NewOp2 = TrCreateValuedLeafNode (PARSEOP_NAMESTRING,
- (ACPI_INTEGER) ACPI_TO_INTEGER (PredicateValueName));
+ (UINT64) ACPI_TO_INTEGER (PredicateValueName));
NewOp->Asl.Next = NewOp2;
TrAmlInitLineNumbers (NewOp2, Predicate);
@@ -612,7 +612,7 @@ TrDoSwitch (
* CaseOp->Child->Peer is the beginning of the case block
*/
NewOp = TrCreateValuedLeafNode (PARSEOP_NAMESTRING,
- (ACPI_INTEGER) ACPI_TO_INTEGER (PredicateValueName));
+ (UINT64) ACPI_TO_INTEGER (PredicateValueName));
NewOp->Asl.Next = Predicate;
TrAmlInitLineNumbers (NewOp, Predicate);
@@ -761,7 +761,7 @@ TrDoSwitch (
/* Create the NameSeg child for the Name node */
NewOp2 = TrCreateValuedLeafNode (PARSEOP_NAMESEG,
- (ACPI_INTEGER) ACPI_TO_INTEGER (PredicateValueName));
+ (UINT64) ACPI_TO_INTEGER (PredicateValueName));
NewOp2->Asl.CompileFlags |= NODE_IS_NAME_DECLARATION;
NewOp->Asl.Child = NewOp2;
@@ -771,22 +771,22 @@ TrDoSwitch (
{
case ACPI_BTYPE_INTEGER:
NewOp2->Asl.Next = TrCreateValuedLeafNode (PARSEOP_ZERO,
- (ACPI_INTEGER) 0);
+ (UINT64) 0);
break;
case ACPI_BTYPE_STRING:
NewOp2->Asl.Next = TrCreateValuedLeafNode (PARSEOP_STRING_LITERAL,
- (ACPI_INTEGER) ACPI_TO_INTEGER (""));
+ (UINT64) ACPI_TO_INTEGER (""));
break;
case ACPI_BTYPE_BUFFER:
(void) TrLinkPeerNode (NewOp2, TrCreateValuedLeafNode (PARSEOP_BUFFER,
- (ACPI_INTEGER) 0));
+ (UINT64) 0));
Next = NewOp2->Asl.Next;
(void) TrLinkChildren (Next, 1, TrCreateValuedLeafNode (PARSEOP_ZERO,
- (ACPI_INTEGER) 1));
+ (UINT64) 1));
(void) TrLinkPeerNode (Next->Asl.Child,
- TrCreateValuedLeafNode (PARSEOP_DEFAULT_ARG, (ACPI_INTEGER) 0));
+ TrCreateValuedLeafNode (PARSEOP_DEFAULT_ARG, (UINT64) 0));
TrAmlSetSubtreeParent (Next->Asl.Child, Next);
break;
@@ -821,7 +821,7 @@ TrDoSwitch (
Predicate->Asl.Parent = StoreOp;
NewOp = TrCreateValuedLeafNode (PARSEOP_NAMESEG,
- (ACPI_INTEGER) ACPI_TO_INTEGER (PredicateValueName));
+ (UINT64) ACPI_TO_INTEGER (PredicateValueName));
NewOp->Asl.Parent = StoreOp;
Predicate->Asl.Next = NewOp;
diff --git a/source/compiler/asltree.c b/source/compiler/asltree.c
index b567c6f97..1167f51be 100644
--- a/source/compiler/asltree.c
+++ b/source/compiler/asltree.c
@@ -490,7 +490,7 @@ TrCreateLeafNode (
ACPI_PARSE_OBJECT *
TrCreateValuedLeafNode (
UINT32 ParseOpcode,
- ACPI_INTEGER Value)
+ UINT64 Value)
{
ACPI_PARSE_OBJECT *Op;
diff --git a/source/compiler/aslutils.c b/source/compiler/aslutils.c
index ca5e52f1d..01db90a30 100644
--- a/source/compiler/aslutils.c
+++ b/source/compiler/aslutils.c
@@ -142,7 +142,7 @@ static ACPI_STATUS
UtStrtoul64 (
char *String,
UINT32 Base,
- ACPI_INTEGER *RetInteger);
+ UINT64 *RetInteger);
static void
UtPadNameWithUnderscores (
@@ -846,12 +846,12 @@ UtAttachNamepathToOwner (
*
******************************************************************************/
-ACPI_INTEGER
+UINT64
UtDoConstant (
char *String)
{
ACPI_STATUS Status;
- ACPI_INTEGER Converted;
+ UINT64 Converted;
char ErrBuf[64];
@@ -888,11 +888,11 @@ static ACPI_STATUS
UtStrtoul64 (
char *String,
UINT32 Base,
- ACPI_INTEGER *RetInteger)
+ UINT64 *RetInteger)
{
UINT32 Index;
UINT32 Sign;
- ACPI_INTEGER ReturnValue = 0;
+ UINT64 ReturnValue = 0;
ACPI_STATUS Status = AE_OK;
@@ -1008,8 +1008,8 @@ UtStrtoul64 (
/* Check to see if value is out of range: */
- if (ReturnValue > ((ACPI_INTEGER_MAX - (ACPI_INTEGER) Index) /
- (ACPI_INTEGER) Base))
+ if (ReturnValue > ((ACPI_UINT64_MAX - (UINT64) Index) /
+ (UINT64) Base))
{
goto ErrorExit;
}
diff --git a/source/components/debugger/dbexec.c b/source/components/debugger/dbexec.c
index dc8ff92bb..da21a1258 100644
--- a/source/components/debugger/dbexec.c
+++ b/source/components/debugger/dbexec.c
@@ -243,7 +243,7 @@ AcpiDbExecuteMethod (
default:
Params[i].Type = ACPI_TYPE_INTEGER;
- Params[i].Integer.Value = i * (ACPI_INTEGER) 0x1000;
+ Params[i].Integer.Value = i * (UINT64) 0x1000;
break;
}
}
@@ -484,7 +484,7 @@ AcpiDbExecute (
* Allow any handlers in separate threads to complete.
* (Such as Notify handlers invoked from AML executed above).
*/
- AcpiOsSleep ((ACPI_INTEGER) 10);
+ AcpiOsSleep ((UINT64) 10);
#ifdef ACPI_DEBUG_OUTPUT
diff --git a/source/components/dispatcher/dsfield.c b/source/components/dispatcher/dsfield.c
index ec3a6be65..8453c8808 100644
--- a/source/components/dispatcher/dsfield.c
+++ b/source/components/dispatcher/dsfield.c
@@ -314,7 +314,7 @@ AcpiDsGetFieldNames (
ACPI_PARSE_OBJECT *Arg)
{
ACPI_STATUS Status;
- ACPI_INTEGER Position;
+ UINT64 Position;
ACPI_FUNCTION_TRACE_PTR (DsGetFieldNames, Info);
@@ -338,8 +338,8 @@ AcpiDsGetFieldNames (
{
case AML_INT_RESERVEDFIELD_OP:
- Position = (ACPI_INTEGER) Info->FieldBitPosition
- + (ACPI_INTEGER) Arg->Common.Value.Size;
+ Position = (UINT64) Info->FieldBitPosition
+ + (UINT64) Arg->Common.Value.Size;
if (Position > ACPI_UINT32_MAX)
{
@@ -406,8 +406,8 @@ AcpiDsGetFieldNames (
/* Keep track of bit position for the next field */
- Position = (ACPI_INTEGER) Info->FieldBitPosition
- + (ACPI_INTEGER) Arg->Common.Value.Size;
+ Position = (UINT64) Info->FieldBitPosition
+ + (UINT64) Arg->Common.Value.Size;
if (Position > ACPI_UINT32_MAX)
{
diff --git a/source/components/dispatcher/dsobject.c b/source/components/dispatcher/dsobject.c
index 64d2dee95..2796f66c7 100644
--- a/source/components/dispatcher/dsobject.c
+++ b/source/components/dispatcher/dsobject.c
@@ -787,7 +787,7 @@ AcpiDsInitObjectFromOp (
case AML_ONES_OP:
- ObjDesc->Integer.Value = ACPI_INTEGER_MAX;
+ ObjDesc->Integer.Value = ACPI_UINT64_MAX;
/* Truncate value if we are executing from a 32-bit ACPI table */
diff --git a/source/components/events/evregion.c b/source/components/events/evregion.c
index 6a2e496dd..f3e10bec8 100644
--- a/source/components/events/evregion.c
+++ b/source/components/events/evregion.c
@@ -442,7 +442,7 @@ Cleanup1:
* RegionOffset - Where in the region to read or write
* BitWidth - Field width in bits (8, 16, 32, or 64)
* Value - Pointer to in or out value, must be
- * full 64-bit ACPI_INTEGER
+ * a full 64-bit integer
*
* RETURN: Status
*
@@ -457,7 +457,7 @@ AcpiEvAddressSpaceDispatch (
UINT32 Function,
UINT32 RegionOffset,
UINT32 BitWidth,
- ACPI_INTEGER *Value)
+ UINT64 *Value)
{
ACPI_STATUS Status;
ACPI_ADR_SPACE_HANDLER Handler;
diff --git a/source/components/events/evrgnini.c b/source/components/events/evrgnini.c
index 8b1740150..8a6cbfd94 100644
--- a/source/components/events/evrgnini.c
+++ b/source/components/events/evrgnini.c
@@ -260,7 +260,7 @@ AcpiEvPciConfigRegionSetup (
void **RegionContext)
{
ACPI_STATUS Status = AE_OK;
- ACPI_INTEGER PciValue;
+ UINT64 PciValue;
ACPI_PCI_ID *PciId = *RegionContext;
ACPI_OPERAND_OBJECT *HandlerObj;
ACPI_NAMESPACE_NODE *ParentNode;
diff --git a/source/components/executer/exconfig.c b/source/components/executer/exconfig.c
index dc6a82408..034afb65c 100644
--- a/source/components/executer/exconfig.c
+++ b/source/components/executer/exconfig.c
@@ -387,7 +387,7 @@ AcpiExRegionRead (
UINT8 *Buffer)
{
ACPI_STATUS Status;
- ACPI_INTEGER Value;
+ UINT64 Value;
UINT32 RegionOffset = 0;
UINT32 i;
diff --git a/source/components/executer/exconvrt.c b/source/components/executer/exconvrt.c
index bd9b5e63c..2e154d120 100644
--- a/source/components/executer/exconvrt.c
+++ b/source/components/executer/exconvrt.c
@@ -129,7 +129,7 @@
static UINT32
AcpiExConvertToAscii (
- ACPI_INTEGER Integer,
+ UINT64 Integer,
UINT16 Base,
UINT8 *String,
UINT8 MaxLength);
@@ -158,7 +158,7 @@ AcpiExConvertToInteger (
{
ACPI_OPERAND_OBJECT *ReturnDesc;
UINT8 *Pointer;
- ACPI_INTEGER Result;
+ UINT64 Result;
UINT32 i;
UINT32 Count;
ACPI_STATUS Status;
@@ -247,7 +247,7 @@ AcpiExConvertToInteger (
* Little endian is used, meaning that the first byte of the buffer
* is the LSB of the integer
*/
- Result |= (((ACPI_INTEGER) Pointer[i]) << (i * 8));
+ Result |= (((UINT64) Pointer[i]) << (i * 8));
}
break;
@@ -389,12 +389,12 @@ AcpiExConvertToBuffer (
static UINT32
AcpiExConvertToAscii (
- ACPI_INTEGER Integer,
+ UINT64 Integer,
UINT16 Base,
UINT8 *String,
UINT8 DataWidth)
{
- ACPI_INTEGER Digit;
+ UINT64 Digit;
UINT32 i;
UINT32 j;
UINT32 k = 0;
@@ -659,7 +659,7 @@ AcpiExConvertToString (
for (i = 0; i < ObjDesc->Buffer.Length; i++)
{
NewBuf += AcpiExConvertToAscii (
- (ACPI_INTEGER) ObjDesc->Buffer.Pointer[i], Base,
+ (UINT64) ObjDesc->Buffer.Pointer[i], Base,
NewBuf, 1);
*NewBuf++ = Separator; /* each separated by a comma or space */
}
diff --git a/source/components/executer/exfield.c b/source/components/executer/exfield.c
index c1ec50cc0..5657ea884 100644
--- a/source/components/executer/exfield.c
+++ b/source/components/executer/exfield.c
@@ -217,7 +217,7 @@ AcpiExReadDataFromField (
/* Call the region handler for the read */
Status = AcpiExAccessRegion (ObjDesc, 0,
- ACPI_CAST_PTR (ACPI_INTEGER, BufferDesc->Buffer.Pointer),
+ ACPI_CAST_PTR (UINT64, BufferDesc->Buffer.Pointer),
Function);
AcpiExReleaseGlobalLock (ObjDesc->CommonField.FieldFlags);
goto Exit;
@@ -226,7 +226,7 @@ AcpiExReadDataFromField (
/*
* Allocate a buffer for the contents of the field.
*
- * If the field is larger than the size of an ACPI_INTEGER, create
+ * If the field is larger than the current integer width, create
* a BUFFER to hold it. Otherwise, use an INTEGER. This allows
* the use of arithmetic operators on the returned value if the
* field size is equal or smaller than an Integer.
@@ -408,7 +408,7 @@ AcpiExWriteDataToField (
* same buffer)
*/
Status = AcpiExAccessRegion (ObjDesc, 0,
- (ACPI_INTEGER *) Buffer, Function);
+ (UINT64 *) Buffer, Function);
AcpiExReleaseGlobalLock (ObjDesc->CommonField.FieldFlags);
*ResultDesc = BufferDesc;
diff --git a/source/components/executer/exfldio.c b/source/components/executer/exfldio.c
index 53c2007ef..403cb0694 100644
--- a/source/components/executer/exfldio.c
+++ b/source/components/executer/exfldio.c
@@ -133,13 +133,13 @@ static ACPI_STATUS
AcpiExFieldDatumIo (
ACPI_OPERAND_OBJECT *ObjDesc,
UINT32 FieldDatumByteOffset,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
UINT32 ReadWrite);
static BOOLEAN
AcpiExRegisterOverflow (
ACPI_OPERAND_OBJECT *ObjDesc,
- ACPI_INTEGER Value);
+ UINT64 Value);
static ACPI_STATUS
AcpiExSetupRegion (
@@ -296,7 +296,7 @@ AcpiExSetupRegion (
* FieldDatumByteOffset - Byte offset of this datum within the
* parent field
* Value - Where to store value (must at least
- * the size of ACPI_INTEGER)
+ * 64 bits)
* Function - Read or Write flag plus other region-
* dependent flags
*
@@ -310,7 +310,7 @@ ACPI_STATUS
AcpiExAccessRegion (
ACPI_OPERAND_OBJECT *ObjDesc,
UINT32 FieldDatumByteOffset,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
UINT32 Function)
{
ACPI_STATUS Status;
@@ -408,7 +408,7 @@ AcpiExAccessRegion (
static BOOLEAN
AcpiExRegisterOverflow (
ACPI_OPERAND_OBJECT *ObjDesc,
- ACPI_INTEGER Value)
+ UINT64 Value)
{
if (ObjDesc->CommonField.BitLength >= ACPI_INTEGER_BIT_SIZE)
@@ -420,7 +420,7 @@ AcpiExRegisterOverflow (
return (FALSE);
}
- if (Value >= ((ACPI_INTEGER) 1 << ObjDesc->CommonField.BitLength))
+ if (Value >= ((UINT64) 1 << ObjDesc->CommonField.BitLength))
{
/*
* The Value is larger than the maximum value that can fit into
@@ -457,11 +457,11 @@ static ACPI_STATUS
AcpiExFieldDatumIo (
ACPI_OPERAND_OBJECT *ObjDesc,
UINT32 FieldDatumByteOffset,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
UINT32 ReadWrite)
{
ACPI_STATUS Status;
- ACPI_INTEGER LocalValue;
+ UINT64 LocalValue;
ACPI_FUNCTION_TRACE_U32 (ExFieldDatumIo, FieldDatumByteOffset);
@@ -543,7 +543,7 @@ AcpiExFieldDatumIo (
* the register
*/
if (AcpiExRegisterOverflow (ObjDesc->BankField.BankObj,
- (ACPI_INTEGER) ObjDesc->BankField.Value))
+ (UINT64) ObjDesc->BankField.Value))
{
return_ACPI_STATUS (AE_AML_REGISTER_LIMIT);
}
@@ -586,7 +586,7 @@ AcpiExFieldDatumIo (
* the register
*/
if (AcpiExRegisterOverflow (ObjDesc->IndexField.IndexObj,
- (ACPI_INTEGER) ObjDesc->IndexField.Value))
+ (UINT64) ObjDesc->IndexField.Value))
{
return_ACPI_STATUS (AE_AML_REGISTER_LIMIT);
}
@@ -615,7 +615,7 @@ AcpiExFieldDatumIo (
"Read from Data Register\n"));
Status = AcpiExExtractFromField (ObjDesc->IndexField.DataObj,
- Value, sizeof (ACPI_INTEGER));
+ Value, sizeof (UINT64));
}
else
{
@@ -626,7 +626,7 @@ AcpiExFieldDatumIo (
ACPI_FORMAT_UINT64 (*Value)));
Status = AcpiExInsertIntoField (ObjDesc->IndexField.DataObj,
- Value, sizeof (ACPI_INTEGER));
+ Value, sizeof (UINT64));
}
break;
@@ -679,13 +679,13 @@ AcpiExFieldDatumIo (
ACPI_STATUS
AcpiExWriteWithUpdateRule (
ACPI_OPERAND_OBJECT *ObjDesc,
- ACPI_INTEGER Mask,
- ACPI_INTEGER FieldValue,
+ UINT64 Mask,
+ UINT64 FieldValue,
UINT32 FieldDatumByteOffset)
{
ACPI_STATUS Status = AE_OK;
- ACPI_INTEGER MergedValue;
- ACPI_INTEGER CurrentValue;
+ UINT64 MergedValue;
+ UINT64 CurrentValue;
ACPI_FUNCTION_TRACE_U32 (ExWriteWithUpdateRule, Mask);
@@ -697,7 +697,7 @@ AcpiExWriteWithUpdateRule (
/* If the mask is all ones, we don't need to worry about the update rule */
- if (Mask != ACPI_INTEGER_MAX)
+ if (Mask != ACPI_UINT64_MAX)
{
/* Decode the update rule */
@@ -787,8 +787,8 @@ AcpiExExtractFromField (
UINT32 BufferLength)
{
ACPI_STATUS Status;
- ACPI_INTEGER RawDatum;
- ACPI_INTEGER MergedDatum;
+ UINT64 RawDatum;
+ UINT64 MergedDatum;
UINT32 FieldOffset = 0;
UINT32 BufferOffset = 0;
UINT32 BufferTailBits;
@@ -917,10 +917,10 @@ AcpiExInsertIntoField (
UINT32 BufferLength)
{
ACPI_STATUS Status;
- ACPI_INTEGER Mask;
- ACPI_INTEGER WidthMask;
- ACPI_INTEGER MergedDatum;
- ACPI_INTEGER RawDatum = 0;
+ UINT64 Mask;
+ UINT64 WidthMask;
+ UINT64 MergedDatum;
+ UINT64 RawDatum = 0;
UINT32 FieldOffset = 0;
UINT32 BufferOffset = 0;
UINT32 BufferTailBits;
@@ -972,7 +972,7 @@ AcpiExInsertIntoField (
*/
if (ObjDesc->CommonField.AccessBitWidth == ACPI_INTEGER_BIT_SIZE)
{
- WidthMask = ACPI_INTEGER_MAX;
+ WidthMask = ACPI_UINT64_MAX;
}
else
{
diff --git a/source/components/executer/exmisc.c b/source/components/executer/exmisc.c
index ac2ba7973..54cb1f001 100644
--- a/source/components/executer/exmisc.c
+++ b/source/components/executer/exmisc.c
@@ -508,11 +508,11 @@ Cleanup:
*
******************************************************************************/
-ACPI_INTEGER
+UINT64
AcpiExDoMathOp (
UINT16 Opcode,
- ACPI_INTEGER Integer0,
- ACPI_INTEGER Integer1)
+ UINT64 Integer0,
+ UINT64 Integer1)
{
ACPI_FUNCTION_ENTRY ();
@@ -615,8 +615,8 @@ AcpiExDoMathOp (
ACPI_STATUS
AcpiExDoLogicalNumericOp (
UINT16 Opcode,
- ACPI_INTEGER Integer0,
- ACPI_INTEGER Integer1,
+ UINT64 Integer0,
+ UINT64 Integer1,
BOOLEAN *LogicalResult)
{
ACPI_STATUS Status = AE_OK;
@@ -690,8 +690,8 @@ AcpiExDoLogicalOp (
BOOLEAN *LogicalResult)
{
ACPI_OPERAND_OBJECT *LocalOperand1 = Operand1;
- ACPI_INTEGER Integer0;
- ACPI_INTEGER Integer1;
+ UINT64 Integer0;
+ UINT64 Integer1;
UINT32 Length0;
UINT32 Length1;
ACPI_STATUS Status = AE_OK;
diff --git a/source/components/executer/exoparg1.c b/source/components/executer/exoparg1.c
index 002ee4d8d..b7ee45968 100644
--- a/source/components/executer/exoparg1.c
+++ b/source/components/executer/exoparg1.c
@@ -368,8 +368,8 @@ AcpiExOpcode_1A_1T_1R (
ACPI_OPERAND_OBJECT *ReturnDesc2 = NULL;
UINT32 Temp32;
UINT32 i;
- ACPI_INTEGER PowerOfTen;
- ACPI_INTEGER Digit;
+ UINT64 PowerOfTen;
+ UINT64 Digit;
ACPI_FUNCTION_TRACE_STR (ExOpcode_1A_1T_1R,
@@ -477,7 +477,7 @@ AcpiExOpcode_1A_1T_1R (
/* Sum the digit into the result with the current power of 10 */
ReturnDesc->Integer.Value +=
- (((ACPI_INTEGER) Temp32) * PowerOfTen);
+ (((UINT64) Temp32) * PowerOfTen);
/* Shift to next BCD digit */
@@ -506,7 +506,7 @@ AcpiExOpcode_1A_1T_1R (
* remainder from above
*/
ReturnDesc->Integer.Value |=
- (((ACPI_INTEGER) Temp32) << ACPI_MUL_4 (i));
+ (((UINT64) Temp32) << ACPI_MUL_4 (i));
}
/* Overflow if there is any data left in Digit */
@@ -553,7 +553,7 @@ AcpiExOpcode_1A_1T_1R (
/* The object exists in the namespace, return TRUE */
- ReturnDesc->Integer.Value = ACPI_INTEGER_MAX;
+ ReturnDesc->Integer.Value = ACPI_UINT64_MAX;
goto Cleanup;
@@ -719,7 +719,7 @@ AcpiExOpcode_1A_0T_1R (
ACPI_OPERAND_OBJECT *ReturnDesc = NULL;
ACPI_STATUS Status = AE_OK;
UINT32 Type;
- ACPI_INTEGER Value;
+ UINT64 Value;
ACPI_FUNCTION_TRACE_STR (ExOpcode_1A_0T_1R,
@@ -745,7 +745,7 @@ AcpiExOpcode_1A_0T_1R (
*/
if (!Operand[0]->Integer.Value)
{
- ReturnDesc->Integer.Value = ACPI_INTEGER_MAX;
+ ReturnDesc->Integer.Value = ACPI_UINT64_MAX;
}
break;
diff --git a/source/components/executer/exoparg2.c b/source/components/executer/exoparg2.c
index 89d417dd5..81eda0e19 100644
--- a/source/components/executer/exoparg2.c
+++ b/source/components/executer/exoparg2.c
@@ -383,7 +383,7 @@ AcpiExOpcode_2A_1T_1R (
{
ACPI_OPERAND_OBJECT **Operand = &WalkState->Operands[0];
ACPI_OPERAND_OBJECT *ReturnDesc = NULL;
- ACPI_INTEGER Index;
+ UINT64 Index;
ACPI_STATUS Status = AE_OK;
ACPI_SIZE Length;
@@ -716,7 +716,7 @@ StoreLogicalResult:
*/
if (LogicalResult)
{
- ReturnDesc->Integer.Value = ACPI_INTEGER_MAX;
+ ReturnDesc->Integer.Value = ACPI_UINT64_MAX;
}
Cleanup:
diff --git a/source/components/executer/exoparg3.c b/source/components/executer/exoparg3.c
index d6768fd87..923337cd2 100644
--- a/source/components/executer/exoparg3.c
+++ b/source/components/executer/exoparg3.c
@@ -239,7 +239,7 @@ AcpiExOpcode_3A_1T_1R (
ACPI_OPERAND_OBJECT *ReturnDesc = NULL;
char *Buffer = NULL;
ACPI_STATUS Status = AE_OK;
- ACPI_INTEGER Index;
+ UINT64 Index;
ACPI_SIZE Length;
diff --git a/source/components/executer/exregion.c b/source/components/executer/exregion.c
index c22fb401a..f551f1768 100644
--- a/source/components/executer/exregion.c
+++ b/source/components/executer/exregion.c
@@ -149,7 +149,7 @@ AcpiExSystemMemorySpaceHandler (
UINT32 Function,
ACPI_PHYSICAL_ADDRESS Address,
UINT32 BitWidth,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
void *HandlerContext,
void *RegionContext)
{
@@ -198,7 +198,7 @@ AcpiExSystemMemorySpaceHandler (
* Hardware does not support non-aligned data transfers, we must verify
* the request.
*/
- (void) AcpiUtShortDivide ((ACPI_INTEGER) Address, Length, NULL, &Remainder);
+ (void) AcpiUtShortDivide ((UINT64) Address, Length, NULL, &Remainder);
if (Remainder != 0)
{
return_ACPI_STATUS (AE_AML_ALIGNMENT);
@@ -211,8 +211,8 @@ AcpiExSystemMemorySpaceHandler (
* 2) Address beyond the current mapping?
*/
if ((Address < MemInfo->MappedPhysicalAddress) ||
- (((ACPI_INTEGER) Address + Length) >
- ((ACPI_INTEGER)
+ (((UINT64) Address + Length) >
+ ((UINT64)
MemInfo->MappedPhysicalAddress + MemInfo->MappedLength)))
{
/*
@@ -282,7 +282,7 @@ AcpiExSystemMemorySpaceHandler (
* access
*/
LogicalAddrPtr = MemInfo->MappedLogicalAddress +
- ((ACPI_INTEGER) Address - (ACPI_INTEGER) MemInfo->MappedPhysicalAddress);
+ ((UINT64) Address - (UINT64) MemInfo->MappedPhysicalAddress);
ACPI_DEBUG_PRINT ((ACPI_DB_INFO,
"System-Memory (width %d) R/W %d Address=%8.8X%8.8X\n",
@@ -304,19 +304,19 @@ AcpiExSystemMemorySpaceHandler (
switch (BitWidth)
{
case 8:
- *Value = (ACPI_INTEGER) ACPI_GET8 (LogicalAddrPtr);
+ *Value = (UINT64) ACPI_GET8 (LogicalAddrPtr);
break;
case 16:
- *Value = (ACPI_INTEGER) ACPI_GET16 (LogicalAddrPtr);
+ *Value = (UINT64) ACPI_GET16 (LogicalAddrPtr);
break;
case 32:
- *Value = (ACPI_INTEGER) ACPI_GET32 (LogicalAddrPtr);
+ *Value = (UINT64) ACPI_GET32 (LogicalAddrPtr);
break;
case 64:
- *Value = (ACPI_INTEGER) ACPI_GET64 (LogicalAddrPtr);
+ *Value = (UINT64) ACPI_GET64 (LogicalAddrPtr);
break;
default:
@@ -383,7 +383,7 @@ AcpiExSystemIoSpaceHandler (
UINT32 Function,
ACPI_PHYSICAL_ADDRESS Address,
UINT32 BitWidth,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
void *HandlerContext,
void *RegionContext)
{
@@ -447,7 +447,7 @@ AcpiExPciConfigSpaceHandler (
UINT32 Function,
ACPI_PHYSICAL_ADDRESS Address,
UINT32 BitWidth,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
void *HandlerContext,
void *RegionContext)
{
@@ -527,7 +527,7 @@ AcpiExCmosSpaceHandler (
UINT32 Function,
ACPI_PHYSICAL_ADDRESS Address,
UINT32 BitWidth,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
void *HandlerContext,
void *RegionContext)
{
@@ -564,7 +564,7 @@ AcpiExPciBarSpaceHandler (
UINT32 Function,
ACPI_PHYSICAL_ADDRESS Address,
UINT32 BitWidth,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
void *HandlerContext,
void *RegionContext)
{
@@ -601,7 +601,7 @@ AcpiExDataTableSpaceHandler (
UINT32 Function,
ACPI_PHYSICAL_ADDRESS Address,
UINT32 BitWidth,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
void *HandlerContext,
void *RegionContext)
{
diff --git a/source/components/executer/exsystem.c b/source/components/executer/exsystem.c
index 05e43290e..9f4583fc1 100644
--- a/source/components/executer/exsystem.c
+++ b/source/components/executer/exsystem.c
@@ -293,7 +293,7 @@ AcpiExSystemDoStall (
ACPI_STATUS
AcpiExSystemDoSuspend (
- ACPI_INTEGER HowLong)
+ UINT64 HowLong)
{
ACPI_FUNCTION_ENTRY ();
diff --git a/source/components/hardware/hwtimer.c b/source/components/hardware/hwtimer.c
index 541b8f1b3..2675dadf3 100644
--- a/source/components/hardware/hwtimer.c
+++ b/source/components/hardware/hwtimer.c
@@ -232,7 +232,7 @@ AcpiGetTimerDuration (
{
ACPI_STATUS Status;
UINT32 DeltaTicks;
- ACPI_INTEGER Quotient;
+ UINT64 Quotient;
ACPI_FUNCTION_TRACE (AcpiGetTimerDuration);
diff --git a/source/components/parser/psargs.c b/source/components/parser/psargs.c
index 539495b41..78127e5d4 100644
--- a/source/components/parser/psargs.c
+++ b/source/components/parser/psargs.c
@@ -514,7 +514,7 @@ AcpiPsGetNextSimpleArg (
/* Get 1 byte from the AML stream */
Opcode = AML_BYTE_OP;
- Arg->Common.Value.Integer = (ACPI_INTEGER) *Aml;
+ Arg->Common.Value.Integer = (UINT64) *Aml;
Length = 1;
break;
diff --git a/source/components/resources/rscreate.c b/source/components/resources/rscreate.c
index f1ed443d0..c2929aa43 100644
--- a/source/components/resources/rscreate.c
+++ b/source/components/resources/rscreate.c
@@ -270,7 +270,7 @@ AcpiRsCreatePciRoutingTable (
/*
* Loop through the ACPI_INTERNAL_OBJECTS - Each object should be a
- * package that in turn contains an ACPI_INTEGER Address, a UINT8 Pin,
+ * package that in turn contains an UINT64 Address, a UINT8 Pin,
* a Name, and a UINT8 SourceIndex.
*/
TopObjectList = PackageObject->Package.Elements;
diff --git a/source/components/utilities/utdebug.c b/source/components/utilities/utdebug.c
index 82f2ffd2b..0a91716f2 100644
--- a/source/components/utilities/utdebug.c
+++ b/source/components/utilities/utdebug.c
@@ -598,7 +598,7 @@ AcpiUtValueExit (
const char *FunctionName,
const char *ModuleName,
UINT32 ComponentId,
- ACPI_INTEGER Value)
+ UINT64 Value)
{
AcpiDebugPrint (ACPI_LV_FUNCTIONS,
diff --git a/source/components/utilities/uteval.c b/source/components/utilities/uteval.c
index 4ee6937d6..c959d44bb 100644
--- a/source/components/utilities/uteval.c
+++ b/source/components/utilities/uteval.c
@@ -423,7 +423,7 @@ ACPI_STATUS
AcpiUtEvaluateNumericObject (
char *ObjectName,
ACPI_NAMESPACE_NODE *DeviceNode,
- ACPI_INTEGER *Value)
+ UINT64 *Value)
{
ACPI_OPERAND_OBJECT *ObjDesc;
ACPI_STATUS Status;
diff --git a/source/components/utilities/utglobal.c b/source/components/utilities/utglobal.c
index 13e85b71b..236d81171 100644
--- a/source/components/utilities/utglobal.c
+++ b/source/components/utilities/utglobal.c
@@ -331,7 +331,7 @@ static const char AcpiGbl_HexToAscii[] =
char
AcpiUtHexToAsciiChar (
- ACPI_INTEGER Integer,
+ UINT64 Integer,
UINT32 Position)
{
diff --git a/source/components/utilities/utmath.c b/source/components/utilities/utmath.c
index 79cf74124..54d492f23 100644
--- a/source/components/utilities/utmath.c
+++ b/source/components/utilities/utmath.c
@@ -149,9 +149,9 @@
ACPI_STATUS
AcpiUtShortDivide (
- ACPI_INTEGER Dividend,
+ UINT64 Dividend,
UINT32 Divisor,
- ACPI_INTEGER *OutQuotient,
+ UINT64 *OutQuotient,
UINT32 *OutRemainder)
{
UINT64_OVERLAY DividendOvl;
@@ -213,10 +213,10 @@ AcpiUtShortDivide (
ACPI_STATUS
AcpiUtDivide (
- ACPI_INTEGER InDividend,
- ACPI_INTEGER InDivisor,
- ACPI_INTEGER *OutQuotient,
- ACPI_INTEGER *OutRemainder)
+ UINT64 InDividend,
+ UINT64 InDivisor,
+ UINT64 *OutQuotient,
+ UINT64 *OutRemainder)
{
UINT64_OVERLAY Dividend;
UINT64_OVERLAY Divisor;
@@ -293,8 +293,8 @@ AcpiUtDivide (
* The 64-bit remainder must be generated.
*/
Partial1 = Quotient.Part.Lo * Divisor.Part.Hi;
- Partial2.Full = (ACPI_INTEGER) Quotient.Part.Lo * Divisor.Part.Lo;
- Partial3.Full = (ACPI_INTEGER) Partial2.Part.Hi + Partial1;
+ Partial2.Full = (UINT64) Quotient.Part.Lo * Divisor.Part.Lo;
+ Partial3.Full = (UINT64) Partial2.Part.Hi + Partial1;
Remainder.Part.Hi = Partial3.Part.Lo;
Remainder.Part.Lo = Partial2.Part.Lo;
@@ -362,9 +362,9 @@ AcpiUtDivide (
ACPI_STATUS
AcpiUtShortDivide (
- ACPI_INTEGER InDividend,
+ UINT64 InDividend,
UINT32 Divisor,
- ACPI_INTEGER *OutQuotient,
+ UINT64 *OutQuotient,
UINT32 *OutRemainder)
{
@@ -395,10 +395,10 @@ AcpiUtShortDivide (
ACPI_STATUS
AcpiUtDivide (
- ACPI_INTEGER InDividend,
- ACPI_INTEGER InDivisor,
- ACPI_INTEGER *OutQuotient,
- ACPI_INTEGER *OutRemainder)
+ UINT64 InDividend,
+ UINT64 InDivisor,
+ UINT64 *OutQuotient,
+ UINT64 *OutRemainder)
{
ACPI_FUNCTION_TRACE (UtDivide);
diff --git a/source/components/utilities/utmisc.c b/source/components/utilities/utmisc.c
index 06bd536a5..37b15e2c4 100644
--- a/source/components/utilities/utmisc.c
+++ b/source/components/utilities/utmisc.c
@@ -929,12 +929,12 @@ ACPI_STATUS
AcpiUtStrtoul64 (
char *String,
UINT32 Base,
- ACPI_INTEGER *RetInteger)
+ UINT64 *RetInteger)
{
UINT32 ThisDigit = 0;
- ACPI_INTEGER ReturnValue = 0;
- ACPI_INTEGER Quotient;
- ACPI_INTEGER Dividend;
+ UINT64 ReturnValue = 0;
+ UINT64 Quotient;
+ UINT64 Dividend;
UINT32 ToIntegerOp = (Base == ACPI_ANY_BASE);
UINT32 Mode32 = (AcpiGbl_IntegerByteWidth == 4);
UINT8 ValidDigits = 0;
@@ -1071,7 +1071,7 @@ AcpiUtStrtoul64 (
/* Divide the digit into the correct position */
- (void) AcpiUtShortDivide ((Dividend - (ACPI_INTEGER) ThisDigit),
+ (void) AcpiUtShortDivide ((Dividend - (UINT64) ThisDigit),
Base, &Quotient, NULL);
if (ReturnValue > Quotient)
diff --git a/source/include/acevents.h b/source/include/acevents.h
index 5af9b9ba3..567ac1ec0 100644
--- a/source/include/acevents.h
+++ b/source/include/acevents.h
@@ -265,7 +265,7 @@ AcpiEvAddressSpaceDispatch (
UINT32 Function,
UINT32 RegionOffset,
UINT32 BitWidth,
- ACPI_INTEGER *Value);
+ UINT64 *Value);
ACPI_STATUS
AcpiEvAttachRegion (
diff --git a/source/include/acinterp.h b/source/include/acinterp.h
index 433f3077b..de7dbf803 100644
--- a/source/include/acinterp.h
+++ b/source/include/acinterp.h
@@ -214,13 +214,13 @@ AcpiExCommonBufferSetup (
ACPI_STATUS
AcpiExWriteWithUpdateRule (
ACPI_OPERAND_OBJECT *ObjDesc,
- ACPI_INTEGER Mask,
- ACPI_INTEGER FieldValue,
+ UINT64 Mask,
+ UINT64 FieldValue,
UINT32 FieldDatumByteOffset);
void
AcpiExGetBufferDatum(
- ACPI_INTEGER *Datum,
+ UINT64 *Datum,
void *Buffer,
UINT32 BufferLength,
UINT32 ByteGranularity,
@@ -228,7 +228,7 @@ AcpiExGetBufferDatum(
void
AcpiExSetBufferDatum (
- ACPI_INTEGER MergedDatum,
+ UINT64 MergedDatum,
void *Buffer,
UINT32 BufferLength,
UINT32 ByteGranularity,
@@ -266,7 +266,7 @@ ACPI_STATUS
AcpiExAccessRegion (
ACPI_OPERAND_OBJECT *ObjDesc,
UINT32 FieldDatumByteOffset,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
UINT32 ReadWrite);
@@ -296,8 +296,8 @@ AcpiExDoConcatenate (
ACPI_STATUS
AcpiExDoLogicalNumericOp (
UINT16 Opcode,
- ACPI_INTEGER Integer0,
- ACPI_INTEGER Integer1,
+ UINT64 Integer0,
+ UINT64 Integer1,
BOOLEAN *LogicalResult);
ACPI_STATUS
@@ -307,11 +307,11 @@ AcpiExDoLogicalOp (
ACPI_OPERAND_OBJECT *Operand1,
BOOLEAN *LogicalResult);
-ACPI_INTEGER
+UINT64
AcpiExDoMathOp (
UINT16 Opcode,
- ACPI_INTEGER Operand0,
- ACPI_INTEGER Operand1);
+ UINT64 Operand0,
+ UINT64 Operand1);
ACPI_STATUS
AcpiExCreateMutex (
@@ -425,7 +425,7 @@ AcpiExSystemDoNotifyOp (
ACPI_STATUS
AcpiExSystemDoSuspend(
- ACPI_INTEGER Time);
+ UINT64 Time);
ACPI_STATUS
AcpiExSystemDoStall (
@@ -697,12 +697,12 @@ AcpiExReleaseGlobalLock (
void
AcpiExEisaIdToString (
char *Dest,
- ACPI_INTEGER CompressedId);
+ UINT64 CompressedId);
void
AcpiExIntegerToString (
char *Dest,
- ACPI_INTEGER Value);
+ UINT64 Value);
/*
@@ -713,7 +713,7 @@ AcpiExSystemMemorySpaceHandler (
UINT32 Function,
ACPI_PHYSICAL_ADDRESS Address,
UINT32 BitWidth,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
void *HandlerContext,
void *RegionContext);
@@ -722,7 +722,7 @@ AcpiExSystemIoSpaceHandler (
UINT32 Function,
ACPI_PHYSICAL_ADDRESS Address,
UINT32 BitWidth,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
void *HandlerContext,
void *RegionContext);
@@ -731,7 +731,7 @@ AcpiExPciConfigSpaceHandler (
UINT32 Function,
ACPI_PHYSICAL_ADDRESS Address,
UINT32 BitWidth,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
void *HandlerContext,
void *RegionContext);
@@ -740,7 +740,7 @@ AcpiExCmosSpaceHandler (
UINT32 Function,
ACPI_PHYSICAL_ADDRESS Address,
UINT32 BitWidth,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
void *HandlerContext,
void *RegionContext);
@@ -749,7 +749,7 @@ AcpiExPciBarSpaceHandler (
UINT32 Function,
ACPI_PHYSICAL_ADDRESS Address,
UINT32 BitWidth,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
void *HandlerContext,
void *RegionContext);
@@ -758,7 +758,7 @@ AcpiExEmbeddedControllerSpaceHandler (
UINT32 Function,
ACPI_PHYSICAL_ADDRESS Address,
UINT32 BitWidth,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
void *HandlerContext,
void *RegionContext);
@@ -767,7 +767,7 @@ AcpiExSmBusSpaceHandler (
UINT32 Function,
ACPI_PHYSICAL_ADDRESS Address,
UINT32 BitWidth,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
void *HandlerContext,
void *RegionContext);
@@ -777,7 +777,7 @@ AcpiExDataTableSpaceHandler (
UINT32 Function,
ACPI_PHYSICAL_ADDRESS Address,
UINT32 BitWidth,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
void *HandlerContext,
void *RegionContext);
diff --git a/source/include/aclocal.h b/source/include/aclocal.h
index cee7334d6..201793bbc 100644
--- a/source/include/aclocal.h
+++ b/source/include/aclocal.h
@@ -853,7 +853,7 @@ typedef struct acpi_opcode_info
typedef union acpi_parse_value
{
- ACPI_INTEGER Integer; /* Integer constant (Up to 64 bits) */
+ UINT64 Integer; /* Integer constant (Up to 64 bits) */
UINT64_STRUCT Integer64; /* Structure overlay for 2 32-bit Dwords */
UINT32 Size; /* bytelist or field size */
char *String; /* NULL terminated string */
diff --git a/source/include/acmacros.h b/source/include/acmacros.h
index 46f977eb2..e9a6f42cb 100644
--- a/source/include/acmacros.h
+++ b/source/include/acmacros.h
@@ -335,8 +335,8 @@
* MASK_BITS_ABOVE creates a mask starting AT the position and above
* MASK_BITS_BELOW creates a mask starting one bit BELOW the position
*/
-#define ACPI_MASK_BITS_ABOVE(position) (~((ACPI_INTEGER_MAX) << ((UINT32) (position))))
-#define ACPI_MASK_BITS_BELOW(position) ((ACPI_INTEGER_MAX) << ((UINT32) (position)))
+#define ACPI_MASK_BITS_ABOVE(position) (~((ACPI_UINT64_MAX) << ((UINT32) (position))))
+#define ACPI_MASK_BITS_BELOW(position) ((ACPI_UINT64_MAX) << ((UINT32) (position)))
/* Bitfields within ACPI registers */
@@ -473,16 +473,16 @@
AcpiUtPtrExit (ACPI_DEBUG_PARAMETERS, (UINT8 *) _s); \
return (_s); })
#define return_VALUE(s) ACPI_DO_WHILE0 ({ \
- register ACPI_INTEGER _s = (s); \
+ register UINT64 _s = (s); \
AcpiUtValueExit (ACPI_DEBUG_PARAMETERS, _s); \
return (_s); })
#define return_UINT8(s) ACPI_DO_WHILE0 ({ \
register UINT8 _s = (UINT8) (s); \
- AcpiUtValueExit (ACPI_DEBUG_PARAMETERS, (ACPI_INTEGER) _s); \
+ AcpiUtValueExit (ACPI_DEBUG_PARAMETERS, (UINT64) _s); \
return (_s); })
#define return_UINT32(s) ACPI_DO_WHILE0 ({ \
register UINT32 _s = (UINT32) (s); \
- AcpiUtValueExit (ACPI_DEBUG_PARAMETERS, (ACPI_INTEGER) _s); \
+ AcpiUtValueExit (ACPI_DEBUG_PARAMETERS, (UINT64) _s); \
return (_s); })
#else /* Use original less-safe macros */
@@ -493,7 +493,7 @@
AcpiUtPtrExit (ACPI_DEBUG_PARAMETERS, (UINT8 *) (s)); \
return((s)); })
#define return_VALUE(s) ACPI_DO_WHILE0 ({ \
- AcpiUtValueExit (ACPI_DEBUG_PARAMETERS, (ACPI_INTEGER) (s)); \
+ AcpiUtValueExit (ACPI_DEBUG_PARAMETERS, (UINT64) (s)); \
return((s)); })
#define return_UINT8(s) return_VALUE(s)
#define return_UINT32(s) return_VALUE(s)
diff --git a/source/include/acobject.h b/source/include/acobject.h
index c9f100c5d..f86f83926 100644
--- a/source/include/acobject.h
+++ b/source/include/acobject.h
@@ -190,7 +190,7 @@ typedef struct acpi_object_integer
{
ACPI_OBJECT_COMMON_HEADER
UINT8 Fill[3]; /* Prevent warning on some compilers */
- ACPI_INTEGER Value;
+ UINT64 Value;
} ACPI_OBJECT_INTEGER;
diff --git a/source/include/acpiosxf.h b/source/include/acpiosxf.h
index c3b780920..0c22b63bb 100644
--- a/source/include/acpiosxf.h
+++ b/source/include/acpiosxf.h
@@ -346,7 +346,7 @@ AcpiOsWaitEventsComplete (
void
AcpiOsSleep (
- ACPI_INTEGER Milliseconds);
+ UINT64 Milliseconds);
void
AcpiOsStall (
@@ -401,7 +401,7 @@ ACPI_STATUS
AcpiOsWritePciConfiguration (
ACPI_PCI_ID *PciId,
UINT32 Reg,
- ACPI_INTEGER Value,
+ UINT64 Value,
UINT32 Width);
diff --git a/source/include/acrestyp.h b/source/include/acrestyp.h
index 0ebc9d13c..0a85d29f5 100644
--- a/source/include/acrestyp.h
+++ b/source/include/acrestyp.h
@@ -534,7 +534,7 @@ typedef struct acpi_pci_routing_table
{
UINT32 Length;
UINT32 Pin;
- ACPI_INTEGER Address; /* here for 64-bit alignment */
+ UINT64 Address; /* here for 64-bit alignment */
UINT32 SourceIndex;
char Source[4]; /* pad to 64 bits so sizeof() works in all cases */
diff --git a/source/include/actypes.h b/source/include/actypes.h
index a6e22d6fd..32219ab97 100644
--- a/source/include/actypes.h
+++ b/source/include/actypes.h
@@ -478,14 +478,6 @@ typedef struct uint32_struct
} UINT32_STRUCT;
-/*
- * Acpi integer width. In ACPI version 1, integers are 32 bits. In ACPI
- * version 2, integers are 64 bits. Note that this pertains to the ACPI integer
- * type only, not other integers used in the implementation of the ACPI CA
- * subsystem.
- */
-typedef UINT64 ACPI_INTEGER;
-#define ACPI_INTEGER_MAX ACPI_UINT64_MAX
#define ACPI_INTEGER_BIT_SIZE 64
#define ACPI_MAX_DECIMAL_DIGITS 20 /* 2^64 = 18,446,744,073,709,551,616 */
#define ACPI_MAX64_DECIMAL_DIGITS 20
@@ -500,6 +492,19 @@ typedef UINT64 ACPI_INTEGER;
#define ACPI_WAIT_FOREVER 0xFFFF /* UINT16, as per ACPI spec */
#define ACPI_DO_NOT_WAIT 0
+/*
+ * Obsolete: Acpi integer width. In ACPI version 1 (1996), integers are 32 bits.
+ * In ACPI version 2 (2000) and later, integers are 64 bits. Note that this
+ * pertains to the ACPI integer type only, not to other integers used in the
+ * implementation of the ACPICA subsystem.
+ *
+ * 01/2010: This type is obsolete and has been removed from the entire ACPICA
+ * code base. It remains here for compatibility with device drivers that use
+ * the type. However, it will be removed in the future.
+ */
+typedef UINT64 ACPI_INTEGER;
+#define ACPI_INTEGER_MAX ACPI_UINT64_MAX
+
/*******************************************************************************
*
@@ -890,7 +895,7 @@ typedef union acpi_object
struct
{
ACPI_OBJECT_TYPE Type; /* ACPI_TYPE_INTEGER */
- ACPI_INTEGER Value; /* The actual number */
+ UINT64 Value; /* The actual number */
} Integer;
struct
@@ -1094,7 +1099,7 @@ ACPI_STATUS (*ACPI_ADR_SPACE_HANDLER) (
UINT32 Function,
ACPI_PHYSICAL_ADDRESS Address,
UINT32 BitWidth,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
void *HandlerContext,
void *RegionContext);
@@ -1164,7 +1169,7 @@ typedef struct acpi_device_info
UINT8 HighestDstates[4]; /* _SxD values: 0xFF indicates not valid */
UINT8 LowestDstates[5]; /* _SxW values: 0xFF indicates not valid */
UINT32 CurrentStatus; /* _STA value */
- ACPI_INTEGER Address; /* _ADR value */
+ UINT64 Address; /* _ADR value */
ACPI_DEVICE_ID HardwareId; /* _HID value */
ACPI_DEVICE_ID UniqueId; /* _UID value */
ACPI_DEVICE_ID_LIST CompatibleIdList; /* _CID list <must be last> */
diff --git a/source/include/acutils.h b/source/include/acutils.h
index a35a9680a..ae406c388 100644
--- a/source/include/acutils.h
+++ b/source/include/acutils.h
@@ -235,7 +235,7 @@ AcpiUtGetEventName (
char
AcpiUtHexToAsciiChar (
- ACPI_INTEGER Integer,
+ UINT64 Integer,
UINT32 Position);
BOOLEAN
@@ -470,7 +470,7 @@ AcpiUtValueExit (
const char *FunctionName,
const char *ModuleName,
UINT32 ComponentId,
- ACPI_INTEGER Value);
+ UINT64 Value);
void
AcpiUtPtrExit (
@@ -550,7 +550,7 @@ ACPI_STATUS
AcpiUtEvaluateNumericObject (
char *ObjectName,
ACPI_NAMESPACE_NODE *DeviceNode,
- ACPI_INTEGER *Value);
+ UINT64 *Value);
ACPI_STATUS
AcpiUtExecute_STA (
@@ -720,16 +720,16 @@ AcpiUtDeleteGenericState (
*/
ACPI_STATUS
AcpiUtDivide (
- ACPI_INTEGER InDividend,
- ACPI_INTEGER InDivisor,
- ACPI_INTEGER *OutQuotient,
- ACPI_INTEGER *OutRemainder);
+ UINT64 InDividend,
+ UINT64 InDivisor,
+ UINT64 *OutQuotient,
+ UINT64 *OutRemainder);
ACPI_STATUS
AcpiUtShortDivide (
- ACPI_INTEGER InDividend,
+ UINT64 InDividend,
UINT32 Divisor,
- ACPI_INTEGER *OutQuotient,
+ UINT64 *OutQuotient,
UINT32 *OutRemainder);
/*
@@ -788,7 +788,7 @@ ACPI_STATUS
AcpiUtStrtoul64 (
char *String,
UINT32 Base,
- ACPI_INTEGER *RetInteger);
+ UINT64 *RetInteger);
void ACPI_INTERNAL_VAR_XFACE
AcpiUtPredefinedWarning (
diff --git a/source/os_specific/service_layers/osunixxf.c b/source/os_specific/service_layers/osunixxf.c
index 70e2ad684..e62ed738b 100644
--- a/source/os_specific/service_layers/osunixxf.c
+++ b/source/os_specific/service_layers/osunixxf.c
@@ -871,7 +871,7 @@ AcpiOsStall (
void
AcpiOsSleep (
- ACPI_INTEGER milliseconds)
+ UINT64 milliseconds)
{
sleep (milliseconds / 1000); /* Sleep for whole seconds */
@@ -976,7 +976,7 @@ ACPI_STATUS
AcpiOsWritePciConfiguration (
ACPI_PCI_ID *PciId,
UINT32 Register,
- ACPI_INTEGER Value,
+ UINT64 Value,
UINT32 Width)
{
diff --git a/source/os_specific/service_layers/oswinxf.c b/source/os_specific/service_layers/oswinxf.c
index adfa080ab..c932c2ca6 100644
--- a/source/os_specific/service_layers/oswinxf.c
+++ b/source/os_specific/service_layers/oswinxf.c
@@ -1146,7 +1146,7 @@ AcpiOsStall (
void
AcpiOsSleep (
- ACPI_INTEGER milliseconds)
+ UINT64 milliseconds)
{
/* Add 10ms to account for clock tick granularity */
@@ -1224,7 +1224,7 @@ ACPI_STATUS
AcpiOsWritePciConfiguration (
ACPI_PCI_ID *PciId,
UINT32 Register,
- ACPI_INTEGER Value,
+ UINT64 Value,
UINT32 Width)
{
diff --git a/source/tools/acpiexec/aecommon.h b/source/tools/acpiexec/aecommon.h
index 6fe34d2bd..7608c5de4 100644
--- a/source/tools/acpiexec/aecommon.h
+++ b/source/tools/acpiexec/aecommon.h
@@ -232,7 +232,7 @@ AeRegionHandler (
UINT32 Function,
ACPI_PHYSICAL_ADDRESS Address,
UINT32 BitWidth,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
void *HandlerContext,
void *RegionContext);
diff --git a/source/tools/acpiexec/aehandlers.c b/source/tools/acpiexec/aehandlers.c
index ea6afdf10..28450cec7 100644
--- a/source/tools/acpiexec/aehandlers.c
+++ b/source/tools/acpiexec/aehandlers.c
@@ -653,7 +653,7 @@ AeRegionHandler (
UINT32 Function,
ACPI_PHYSICAL_ADDRESS Address,
UINT32 BitWidth,
- ACPI_INTEGER *Value,
+ UINT64 *Value,
void *HandlerContext,
void *RegionContext)
{
@@ -918,8 +918,8 @@ AeRegionHandler (
* NOTE: RegionElement->Length is in bytes, therefore it we compare against
* ByteWidth (see above)
*/
- if (((ACPI_INTEGER) Address + ByteWidth) >
- ((ACPI_INTEGER)(RegionElement->Address) + RegionElement->Length))
+ if (((UINT64) Address + ByteWidth) >
+ ((UINT64)(RegionElement->Address) + RegionElement->Length))
{
ACPI_WARNING ((AE_INFO,
"Request on [%4.4s] is beyond region limit Req-%X+%X, Base=%X, Len-%X",
@@ -934,7 +934,7 @@ AeRegionHandler (
* Get BufferValue to point to the "address" in the buffer
*/
BufferValue = ((UINT8 *) RegionElement->Buffer +
- ((ACPI_INTEGER) Address - (ACPI_INTEGER) RegionElement->Address));
+ ((UINT64) Address - (UINT64) RegionElement->Address));
DoFunction:
diff --git a/source/tools/acpisrc/astable.c b/source/tools/acpisrc/astable.c
index 21b45b97f..513c740a1 100644
--- a/source/tools/acpisrc/astable.c
+++ b/source/tools/acpisrc/astable.c
@@ -781,12 +781,15 @@ ACPI_CONVERSION_TABLE StatsConversionTable = {
ACPI_STRING_TABLE CustomReplacements[] = {
- {"(c) 1999 - 2009", "(c) 1999 - 2010", REPLACE_WHOLE_WORD}, /* Main ACPICA source */
- {"(c) 2006 - 2009", "(c) 2006 - 2010", REPLACE_WHOLE_WORD}, /* Test suites */
+ {"ACPI_INTEGER_MAX", "ACPI_UINT64_MAX", REPLACE_WHOLE_WORD},
#if 0
+ {"(ACPI_INTEGER)", "(UINT64)", REPLACE_WHOLE_WORD},
+ {"ACPI_INTEGER ", "UINT64 ", REPLACE_WHOLE_WORD},
+ {"ACPI_INTEGER", "UINT64", REPLACE_WHOLE_WORD},
+ {"(c) 1999 - 2009", "(c) 1999 - 2010", REPLACE_WHOLE_WORD}, /* Main ACPICA source */
+ {"(c) 2006 - 2009", "(c) 2006 - 2010", REPLACE_WHOLE_WORD}, /* Test suites */
{"#include \"acpi.h\"", "#include \"acpi.h\"\n#include \"accommon.h\"", REPLACE_SUBSTRINGS},
- {"(c) 1999 - 2010", "(c) 1999 - 2010", REPLACE_WHOLE_WORD},
{"AcpiTbSumTable", "AcpiTbSumTable", REPLACE_WHOLE_WORD},
{"ACPI_SIG_BOOT", "ACPI_SIG_BOOT", REPLACE_WHOLE_WORD},
{"ACPI_SIG_DBGP", "ACPI_SIG_DBGP", REPLACE_WHOLE_WORD},
diff --git a/source/components/executer/exoparg6.c b/source/components/executer/exoparg6.c
index fb9160e1c..5b35710c9 100644
--- a/source/components/executer/exoparg6.c
+++ b/source/components/executer/exoparg6.c
@@ -305,7 +305,7 @@ AcpiExOpcode_6A_0T_1R (
ACPI_OPERAND_OBJECT **Operand = &WalkState->Operands[0];
ACPI_OPERAND_OBJECT *ReturnDesc = NULL;
ACPI_STATUS Status = AE_OK;
- ACPI_INTEGER Index;
+ UINT64 Index;
ACPI_OPERAND_OBJECT *ThisElement;
@@ -344,9 +344,9 @@ AcpiExOpcode_6A_0T_1R (
}
/* Create an integer for the return value */
- /* Default return value is ACPI_INTEGER_MAX if no match found */
+ /* Default return value is ACPI_UINT64_MAX if no match found */
- ReturnDesc = AcpiUtCreateIntegerObject (ACPI_INTEGER_MAX);
+ ReturnDesc = AcpiUtCreateIntegerObject (ACPI_UINT64_MAX);
if (!ReturnDesc)
{
Status = AE_NO_MEMORY;
@@ -362,7 +362,7 @@ AcpiExOpcode_6A_0T_1R (
*
* Upon finding a match, the loop will terminate via "break" at
* the bottom. If it terminates "normally", MatchValue will be
* ACPI_INTEGER_MAX (Ones) (its initial value) indicating that no
* match was found.
*/
for ( ; Index < Operand[0]->Package.Count; Index++)
@@ -362,7 +362,7 @@ AcpiExOpcode_6A_0T_1R (
* Upon finding a match, the loop will terminate via "break" at
* the bottom. If it terminates "normally", MatchValue will be
- * ACPI_INTEGER_MAX (Ones) (its initial value) indicating that no
+ * ACPI_UINT64_MAX (Ones) (its initial value) indicating that no
* match was found.
*/
diff --git a/source/components/executer/exutils.c b/source/components/executer/exutils.c
index 4d72a0952..d8815aa51 100644
--- a/source/components/executer/exutils.c
+++ b/source/components/executer/exutils.c
@@ -144,7 +144,7 @@
static UINT32
AcpiExDigitsNeeded (
- ACPI_INTEGER Value,
+ UINT64 Value,
UINT32 Base);
@@ -334,7 +334,7 @@ AcpiExTruncateFor32bitTable (
* We are running a method that exists in a 32-bit ACPI table.
* Truncate the value to 32 bits by zeroing out the upper 32-bit field
*/
- ObjDesc->Integer.Value &= (ACPI_INTEGER) ACPI_UINT32_MAX;
+ ObjDesc->Integer.Value &= (UINT64) ACPI_UINT32_MAX;
}
}
@@ -446,17 +446,17 @@ AcpiExReleaseGlobalLock (
static UINT32
AcpiExDigitsNeeded (
- ACPI_INTEGER Value,
+ UINT64 Value,
UINT32 Base)
{
UINT32 NumDigits;
- ACPI_INTEGER CurrentValue;
+ UINT64 CurrentValue;
ACPI_FUNCTION_TRACE (ExDigitsNeeded);
/* ACPI_INTEGER is unsigned, so we don't worry about a '-' prefix */
if (Value == 0)
{
@@ -497,7 +497,7 @@ AcpiExDigitsNeeded (
void
AcpiExEisaIdToString (
char *OutString,
- ACPI_INTEGER CompressedId)
+ UINT64 CompressedId)
{
UINT32 SwappedId;
@@ -523,10 +523,10 @@ AcpiExEisaIdToString (
OutString[0] = (char) (0x40 + (((unsigned long) SwappedId >> 26) & 0x1F));
OutString[1] = (char) (0x40 + ((SwappedId >> 21) & 0x1F));
OutString[2] = (char) (0x40 + ((SwappedId >> 16) & 0x1F));
- OutString[3] = AcpiUtHexToAsciiChar ((ACPI_INTEGER) SwappedId, 12);
- OutString[4] = AcpiUtHexToAsciiChar ((ACPI_INTEGER) SwappedId, 8);
- OutString[5] = AcpiUtHexToAsciiChar ((ACPI_INTEGER) SwappedId, 4);
- OutString[6] = AcpiUtHexToAsciiChar ((ACPI_INTEGER) SwappedId, 0);
+ OutString[3] = AcpiUtHexToAsciiChar ((UINT64) SwappedId, 12);
+ OutString[4] = AcpiUtHexToAsciiChar ((UINT64) SwappedId, 8);
+ OutString[5] = AcpiUtHexToAsciiChar ((UINT64) SwappedId, 4);
+ OutString[6] = AcpiUtHexToAsciiChar ((UINT64) SwappedId, 0);
OutString[7] = 0;
}
@@ -551,7 +551,7 @@ AcpiExEisaIdToString (
void
AcpiExIntegerToString (
char *OutString,
- ACPI_INTEGER Value)
+ UINT64 Value)
{
UINT32 Count;
UINT32 DigitsNeeded;
@@ -446,17 +446,17 @@ AcpiExReleaseGlobalLock (
ACPI_FUNCTION_TRACE (ExDigitsNeeded);
- /* ACPI_INTEGER is unsigned, so we don't worry about a '-' prefix */
+ /* UINT64 is unsigned, so we don't worry about a '-' prefix */
if (Value == 0)
{